using System;

namespace Actimizer.LRM.Contracts
{
    public enum IncomingCallResult {
        /// <summary>
        /// The callers phone number is not vissible.
        /// </summary>
        NoANumber = 0,

        /// <summary>
        /// There is no item call with that phone number.
        /// </summary>
        NoLeadFound = 1,

        /// <summary>
        /// The item cannot be locked.
        /// </summary>
        LeadLockFailed = 2,

        /// <summary>
        /// The item is already processed.
        /// </summary>
        LeadAlreadyProcessed = 3,

        /// <summary>
        /// There is no agent available with access rights to this item.
        /// </summary>
        NoAgentAvailable = 4,

        /// <summary>
        /// The caller hung up.
        /// </summary>
        CallerHungUp = 5,

        /// <summary>
        /// Temporary value used while waiting for an agent.
        /// </summary>
        Connecting = 6,

        /// <summary>
        /// The incoming call was connected.
        /// </summary>
        Connected = 7,

        /// <summary>
        /// The incoming call has timed out waiting for an agent.
        /// </summary>
        Timeout = 8,

        /// <summary>
        /// The incoming call added to dialback queue
        /// </summary>
        DialbackQueued = 9,

        DialbackExpired = 10,

        DialbackDelegated = 11,

        DialbackCancelled = 12,

        ClosedHours = 13,

        TransferredOnClosedHours = 14
    }

    public enum IncomingCallType { External = 0, InternalLeadTransfer = 1 }

    public class IncomingCall
    {
        public string UniqueId { get; set; }

        public DateTime ArrivalTime { get; private set; }
        public string CallingNumber { get; private set; }
        public string CalledNumber { get; private set; }

        public string LeadCallUniqueId { get; internal set; }
        public string LeadUniqueId { get; internal set; }
        public IncomingCallResult? Result { get; protected set; }
        public bool Transfered { get; internal set; }

        public DateTime? ProcessedTime { get; protected set; }
    }
}
