namespace Actimizer.LRM.Contracts
{
	/// <summary>
	/// This enum contains system closures which can be set on leads.
	/// The closure is not selected directly by the agent, but rather inferred
	/// from whatever lead data entry that has been mapped to system closures.
	/// </summary>
    public enum LeadClosure
    {
		/// <summary>
		/// The closure has not yet been set.
		/// </summary>
        NotSet = 0,

		/// <summary>
		/// The lead was closed as a success.
		/// </summary>
        Success = 1,

		/// <summary>
		/// The lead was closed as not interested.
		/// </summary>
        NotInterested = 2,

		/// <summary>
		/// The was closed as invalid. An example would be because if 
		/// phonenumber was to a fax or to the wrong person.
		/// </summary>
        InvalidLead = 3,

		/// <summary>
		/// The lead was closed as unqualified. An example could be that the
		/// lead was a truck driver, but the campaign is about calling 
		/// carpenters.
		/// </summary>
        Unqualified = 4,
    }
}