using System;
using System.Collections.Generic;

namespace Actimizer.LRM.Contracts
{
    public enum SemanticEntryType
    {
        ShortText = 1,
        LongText = 2,
        Time = 3,
        Date = 4,
        DateAndTime = 5,
        Integer = 6,
        Decimal = 7,
        Bool = 8,
        Phone = 9,
        SensitivePhone = 129,
        MobilePhone = 128,
        SensitiveMobilePhone = 130,

        Email = 10,
        SensitiveEmail = 131,
        PickList = 11,
        ZipCode = 13, // Too danish. Currently restricted to 4 digits.
        Notes = 15,

        SocialSecurityNumber = 16,

        BankRegistrationNumber = 17,
        BankAccountNumber = 18,
        BankRegistrationAccountNumber = 30,

        Revenue = 33,
        Profit = 34,
        Commision = 35,
        Points = 36,

        MainClosure = 60,
        SubClosure = 61,

        URL = 102,
        Label = 103,

        BookingEntry = 112,
        BookingCalendarCode = 113,
        BookingTime = 114,


        //Added from DB
        UnitPrice = 104,
        NUnitsSold = 105,

        //NEW
        Birthday = 116,
        FullName = 117,
        FirstName = 118,
        LastName = 119,
        Address = 120,
        Country = 121,
        City = 122,
        City2 = 133,
        Street = 123,
        BuildingNumber = 124,
        ApartmentNumber = 125,
        ApartmentDoor = 134,
        SensitiveInteger = 126,
        SensitiveText = 127,

        SubscriptionStartDate = 132,

        OrderConfirmation = 135
    }

    public enum EntryCategory
    {
        MasterData,
        ResultData
    }

    public class LeadDefinitionEntry
    {
        public required string UniqueId { get; init; }
        public required string UniqueLeadDefinitionId { get; init; }

        public required string DisplayName { get; init; }
        public required string ImportName { get; init; }
        public required string ExportName { get; init; }

        public required EntryCategory? EntryCategory { get; init; }
        public required bool RequiredOnUpload { get; init; }
        public required bool RequiredOnClosure { get; init; }
        public required bool Editable { get; init; }
        public required int SortOrder { get; init; }
        public required int? ArchiveSortOrder { get; init; }
        public required bool IsRestricted { get; init; }
        public required bool VisibleToPartners { get; init; }
        public required int? LowerBound { get; init; }
        public required int? UpperBound { get; init; }
        public required int? RetentionLimitInDays { get; init; }
        public required bool IsDuplicateSearchKey { get; init; }

        public required string CompositionTemplate { get; init; }

        public required IEnumerable<LeadDefinitionEntryOption> ValueOptions { get; init; }
        //public required string Features { get; init; }

        public required bool IsDeleted { get; init; }

        public required string KeyInEntryGroup { get; init; }
        public required LeadDefinitionEntryGroup EntryGroup { get; init; }

        // Type.
        public required SemanticEntryType? SemanticType { get; init; }
        public required string DataType { get; init; }
        public required string RegExp { get; init; }
        public required string RegExpFlags { get; init; }

        //[Obsolete]
        public required string Culture { get; init; } = "";
        public required string Format { get; init; }
    }

    public class LeadDefinitionEntryOption
    {
        public required string Name { get; init; }
        public required string Value { get; init; }
        public required Contracts.LeadClosure? Closure { get; init; }
        public required Contracts.LeadClosure? ClosureCondition { get; init; }
    }

    public class LeadDefinitionEntryGroup
    {
        public required string Name { get; init; }
    }

    public class LeadDefinition
    {
        public string UniqueId { get; set; }

        public string Name { get; set; }

        public DateTime CreatedTime { get; set; }
        public DateTime LastModifiedTime { get; set; }

        public bool IsDeleted { get; set; }

        public IEnumerable<LeadDefinitionEntry> LeadDefinitionEntries { get; set; }
    }

}
