using System.Runtime.Serialization;


namespace Actimizer.LRM.Contracts
{
    public enum LeadImportResultCode
    {
        CampaignNotFound = 0,
        CampaignNotUnique = 1,
        OrgCodeNotFound = 2,
        NoLeadData = 3,
        NoPhoneNumberFound = 4,
        FieldInvalid = 5,
        FieldRequired = 6,
        FieldUnknown = 7,
        FieldIsNotUnique = 8,
        HeaderIsDuplicate = 9,
        DuplicatesFound_Notification = 10,
        DuplicatesFound_Discarded = 11,
        DuplicatesFound_Deactivated = 12,
        DuplicatesFound_Removed = 13,
        CampaignNotAccessible = 14,
        CustomDataTooBig = 15,
        DoNotCall = 16,

        MasterLeadNotFound = 101,
        MasterLeadNotAccessible = 102,
        MasterLeadIsLocked = 103,
        InvalidUniqueId = 106,
        NoFilterMatch = 110,
        InvalidLeadSegmentId = 111,
        LeadSegmentNotAccessible = 112,

        OtherError = 255
    }


    public enum LeadImportResultCodeCategory
    {
        NotSet = 0,
        Information = 1,
        Warning = 2,
        Error = 3,
        Forbidden = 4,

        Unknown = 255
    }


    public static class LeadImportResultCodeExtensions
    {
        public static LeadImportResultCodeCategory GetCategory( this LeadImportResultCode resultCode )
        {
            switch (resultCode)
            {
                case LeadImportResultCode.DuplicatesFound_Notification:
                    return LeadImportResultCodeCategory.Information;

                case LeadImportResultCode.DuplicatesFound_Discarded:
                case LeadImportResultCode.DuplicatesFound_Deactivated:
                case LeadImportResultCode.DuplicatesFound_Removed:
                case LeadImportResultCode.DoNotCall:
                    return LeadImportResultCodeCategory.Warning;

                case LeadImportResultCode.CampaignNotFound:
                case LeadImportResultCode.CampaignNotUnique:
                case LeadImportResultCode.OrgCodeNotFound:
                case LeadImportResultCode.NoLeadData:
                case LeadImportResultCode.NoPhoneNumberFound:
                case LeadImportResultCode.FieldInvalid:
                case LeadImportResultCode.FieldRequired:
                case LeadImportResultCode.FieldUnknown:
                case LeadImportResultCode.FieldIsNotUnique:
                case LeadImportResultCode.HeaderIsDuplicate:
                case LeadImportResultCode.CustomDataTooBig:
                case LeadImportResultCode.OtherError:
                    return LeadImportResultCodeCategory.Error;

                case LeadImportResultCode.CampaignNotAccessible:
                    return LeadImportResultCodeCategory.Forbidden;

                default:
                    return LeadImportResultCodeCategory.Unknown;
            }
        }

        public static LeadImportResultCodeCategory GetCategory( this LeadImportResultCode? resultCode )
        {
            return resultCode == null ? LeadImportResultCodeCategory.NotSet : resultCode.Value.GetCategory();
        }
    }


    [DataContract]
    public class LeadImportResult : NewEntityResult
    {
        [DataMember( EmitDefaultValue = false )]
        public LeadImportResultCode? ResultCode  { get; set; }

        [DataMember( EmitDefaultValue = false )]
        public string ResultData { get; set; }

        [DataMember( EmitDefaultValue = false )]
        public string[] UniqueIdsOfDuplicates { get; set; }
    }
}
