﻿namespace Actimizer.LRM.Contracts
{
	/// <summary>
	/// This enum contains the statuses that describe the possible states a lead can be in before dialing.
	/// </summary>
    public enum PreCallStatus
    {
        /// <summary>
        /// New lead. Never before dialed.
        /// </summary>
        New = 0,

		/// <summary>
		/// This status is set if a call ended with NoResponse, Busy, VoiceMail.
		/// This status is only set if the previous lead state was New or
		/// RedialAutomatic. Common and private redials are never set to this
		/// state.
		/// </summary>
        RedialAutomatic = 1,

		/// <summary>
		/// This status is set when an agent schedules a redial and makes it
		/// available to all agents.
		/// </summary>
        RedialManualCommon = 2,

		/// <summary>
		/// This status is set when an agent schedules a redial and makes it
		/// private.
		/// </summary>
        RedialManualPrivate = 3,

        /// <summary>
        /// This status is set when an agent schedules a redial and makes it
        /// VIP.
        /// </summary>
        VIPRedial = 10,

		/// <summary>
		/// This status is set when an agent doesn't save a called lead on the
		/// contact page. The state is not set immediately, but rather next
		/// time the agent tries to call a lead, on logout, on session timeout
		/// or during nightly cleanup cycle. This status is unique to leads.
		/// </summary>
        Unresolved = 150,

        /// <summary>
        /// This call was succeeded by a call to the next number found on the lead and so
        /// didn't result in a lead status change. This status is unique to calls.
        /// </summary>
        NextNumberDialed = 198,

        /// <summary>
        /// This call was succeeded by a call to an alternative number and so,
        /// didn't result in a lead status change. This status is unique to calls.
        /// </summary>
        AlternativeNumberDialed = 199,
    }
}
