using System.Collections.Generic;
using System.ComponentModel;
using System.Runtime.Serialization;

namespace Actimizer.LRM.Contracts
{
    [DataContract]
    public record User
    {
        [DataMember( IsRequired = true )]
        public required string UniqueId { get; init; }

        [DataMember( IsRequired=true )]
        public required string Username { get; init; }

        [DataMember( IsRequired=true )]
        public required string Name { get; init; }

        [Description( "The organizational code for this user" )]
        [DataMember( IsRequired=true )]
        public required string OrgCode { get; init; }

        [Description( "The users email address. Used for forgotten password, email and sms text merging." )]
        [DataMember( IsRequired = false )]
        public required string Email { get; init; }

        [Description( "The users inbound phone number. Used for email and sms text merging." )]
        [DataMember( IsRequired = false )]
        public required string InboundPhoneNumber { get; init; }

        [Description("The organizational unit this user belongs to")]
        [DataMember( IsRequired=false )]
        public required OrgUnit Parent { get; init; }

        [Description( "Active campaigns that this user currently have access to")]
        [DataMember( IsRequired=false )]
        public required IEnumerable<Campaign> Campaigns { get; init; }

        [Description( "The projects of the campaigns that this user currently have access to" )]
        [DataMember(IsRequired=false)]
        public required IEnumerable<string> Projects { get; init; }

        [Description( "The roles that this user is assigned to" )]
        [DataMember( IsRequired = false )]
        public required IEnumerable<string> Roles { get; init; }

        [Description( "The users employee number. Used for TimeTrack reports." )]
        [DataMember( IsRequired = false )]
        public required string EmployeeNumber { get; init; }

        [Description( "The users payroll number. Used for TimeTrack reports." )]
        [DataMember( IsRequired = false )]
        public required string PayrollNumber { get; init; }
    }
}
